# coding: utf-8
import os
import unittest

import mock
from mako.template import Template
from tornado.escape import to_unicode


class UINamespaceTest(unittest.TestCase):
    def setUp(self):
        path = os.path.join(os.path.dirname(__file__), 'templates')
        self.tpl = Template(filename=os.path.join(path, 'uimodule.html'))

    def test_ui_function_imports_uimodule(self):
        result = self.tpl.render(handler=mock.MagicMock())
        content = to_unicode(result).strip()
        self.assertEqual(content, u'arg1=value1|arg2=value2')



# coding: utf-8
from mako.runtime import supports_caller


@supports_caller
def ui(context, uiclass, **kwargs):
    parts = uiclass.split('.')
    class_ = parts.pop()
    module = '.'.join(parts)

    uimodule = __import__(module, globals(), locals(), [class_], -1)
    instance = getattr(uimodule, class_)(context['handler'])
    return instance.render(**kwargs)



# coding: utf-8
import os

from mako.lookup import TemplateLookup
from tornado.template import Loader


class MakoTemplateLoader(Loader):
    def __init__(self, root_directory, **kwargs):
        super(MakoTemplateLoader, self).__init__(root_directory, **kwargs)
        path = os.path.abspath(root_directory)
        self._lookup = TemplateLookup(directories=path, input_encoding='utf-8',
                                      output_encoding='utf-8',
                                      default_filters=['decode.utf8'])

    def _create_template(self, name):
        template = self._lookup.get_template(name)
        template.generate = template.render

        return template



# coding: utf-8
import os
import unittest

from tornado.escape import to_unicode

from tomako.loader import MakoTemplateLoader


class MakoTemplateLoaderTest(unittest.TestCase):
    def setUp(self):
        path = os.path.join(os.path.dirname(__file__), "templates")
        self.loader = MakoTemplateLoader(path)

    def test_mako_syntax_in_utf8_file(self):
        tmpl = self.loader.load("utf8.html")
        result = tmpl.generate(name='my friend')
        self.assertEqual(to_unicode(result).strip(), u"H\u00e9llo my friend")



# -*- coding: utf-8 -*-
import os

from setuptools import setup, find_packages


README_FILE = os.path.join(os.path.dirname(__file__), 'README.rst')

setup(
    name='tomako',
    version='0.1.0.post1',
    description='Tomako is the easiest way to use Mako as a template engine '
                'for Tornado',
    long_description=open(README_FILE).read(),
    keywords=['tomako', 'mako', 'tornado'],
    author='Rodrigo Machado',
    author_email='rcmachado@gmail.com',
    url='https://github.com/rcmachado/tomako',
    license='MIT',
    packages=find_packages(),
    package_dir={'tomako': 'tomako'},
    install_requires=[
        "tornado>=2.3",
        "Mako>=0.7.2",
    ],
    include_package_data=True
)
